==> idrive-common-neo4j-1.1-20251017.070833-11-sources.jar: com/digiwin/athena/idrive/neo4j/Neo4j1Config.java <==
package com.digiwin.athena.idrive.neo4j;

import lombok.Getter;
import lombok.Setter;
//import org.neo4j.driver.v1.AuthTokens;
//import org.neo4j.driver.v1.Config;
//import org.neo4j.driver.v1.GraphDatabase;
import org.neo4j.driver.AuthTokens;
import org.neo4j.driver.Config;
import org.neo4j.driver.GraphDatabase;
import org.neo4j.ogm.driver.Driver;
//import org.neo4j.ogm.drivers.bolt.driver.BoltDriver;
import org.neo4j.ogm.drivers.bolt.driver.BoltDriver;
import org.neo4j.ogm.session.SessionFactory;
import org.springframework.boot.autoconfigure.AutoConfigurationPackages;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.domain.EntityScanPackages;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.neo4j.core.Neo4jClient;
import org.springframework.data.neo4j.core.Neo4jTemplate;
import org.springframework.data.neo4j.core.transaction.Neo4jTransactionManager;
//import org.springframework.data.neo4j.transaction.Neo4jTransactionManager;

import java.util.List;
import java.util.concurrent.TimeUnit;

@Configuration
@ConditionalOnProperty(value = "spring.data.neo4j.domain1.enable", havingValue = "true")
//@EnableNeo4jRepositories(transactionManagerRef = Neo4j1Config.TRANSACTION_MANAGER,neo4jTemplateRef =Neo4j1Config.NEO4JTEMPLATE)
@ConfigurationProperties(prefix = "spring.data.neo4j.domain1")
@Setter
@Getter
public class Neo4j1Config {

    {
        System.out.println("Neo4j1Config........");
    }
    public static final String NEO4JTEMPLATE = "NEO4JTEMPLATEDOMIAN1";
    public static final String SESSION_FACTORY = "sessionFactoryForDomain1";
    public static final String TRANSACTION_MANAGER = "transactionManagerForDomain1";

    private String uri;

    private String username;

    private String password;

    private Boolean enable;

    @Bean("neo4jDriverDomain1")
    public org.neo4j.driver.Driver neo4jDriverDomain1() {
        System.out.println("neo4jDriverDomain1... url=" + this.uri + ",username=" + this.username + ",password=" + this.password);

        Config config = Config.builder()
                .withConnectionTimeout(10, TimeUnit.SECONDS)
                .withConnectionLivenessCheckTimeout(2, TimeUnit.MINUTES)
                .withMaxConnectionLifetime(4, TimeUnit.MINUTES)
                .withMaxConnectionPoolSize(20)
                .withConnectionAcquisitionTimeout(1, TimeUnit.MINUTES)
                .build();
        return GraphDatabase.driver(this.uri, AuthTokens.basic(this.username, this.password), config);
    }

    @Bean("ogmDriverDomain1")
    public Driver ogmDriverDomain1() {
        Driver ogmDriver = new BoltDriver(neo4jDriverDomain1());
        return ogmDriver;
    }

    @Bean(name = SESSION_FACTORY)
    public SessionFactory sessionFactory(ApplicationContext applicationContext) {
        String[] packages = getPackagesToScan(applicationContext);
        return new SessionFactory(ogmDriverDomain1(), packages);
    }

    @Bean(NEO4JTEMPLATE)
    public Neo4jTemplate neo4jTemplate1(){

        return new Neo4jTemplate(Neo4jClient.create(neo4jDriverDomain1()));

    }

    @Bean(name = TRANSACTION_MANAGER) // <3>
    public Neo4jTransactionManager neo4jTransactionManager(ApplicationContext applicationContext) {
        System.out.println("==========neo4jTransactionManager1==========");
        return new Neo4jTransactionManager(neo4jDriverDomain1());
    }

    private String[] getPackagesToScan(ApplicationContext applicationContext) {
        List<String> packages = EntityScanPackages.get(applicationContext)
                .getPackageNames();
        if (packages.isEmpty() && AutoConfigurationPackages.has(applicationContext)) {
            packages = AutoConfigurationPackages.get(applicationContext);
        }
        return org.springframework.util.StringUtils.toStringArray(packages);
    }
}

==> idrive-common-neo4j-1.1-20251020.034348-12-sources.jar: com/digiwin/athena/idrive/neo4j/Neo4j1Config.java <==
package com.digiwin.athena.idrive.neo4j;

import lombok.Getter;
import lombok.Setter;
//import org.neo4j.driver.v1.AuthTokens;
//import org.neo4j.driver.v1.Config;
//import org.neo4j.driver.v1.GraphDatabase;
import org.neo4j.driver.AuthTokens;
import org.neo4j.driver.Config;
import org.neo4j.driver.GraphDatabase;
import org.neo4j.ogm.driver.Driver;
//import org.neo4j.ogm.drivers.bolt.driver.BoltDriver;
import org.neo4j.ogm.drivers.bolt.driver.BoltDriver;
import org.neo4j.ogm.session.SessionFactory;
import org.springframework.boot.autoconfigure.AutoConfigurationPackages;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.domain.EntityScanPackages;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.neo4j.core.Neo4jClient;
import org.springframework.data.neo4j.core.Neo4jTemplate;
import org.springframework.data.neo4j.core.transaction.Neo4jTransactionManager;
//import org.springframework.data.neo4j.transaction.Neo4jTransactionManager;

import java.util.List;
import java.util.concurrent.TimeUnit;

@Configuration
@ConditionalOnProperty(value = "spring.data.neo4j.domain1.enable", havingValue = "true")
//@EnableNeo4jRepositories(transactionManagerRef = Neo4j1Config.TRANSACTION_MANAGER,neo4jTemplateRef =Neo4j1Config.NEO4JTEMPLATE)
@ConfigurationProperties(prefix = "spring.data.neo4j.domain1")
@Setter
@Getter
public class Neo4j1Config {

    {
        System.out.println("Neo4j1Config........");
    }
    public static final String NEO4JTEMPLATE = "NEO4JTEMPLATEDOMIAN1";
    public static final String SESSION_FACTORY = "sessionFactoryForDomain1";
    public static final String TRANSACTION_MANAGER = "transactionManagerForDomain1";

    private String uri;

    private String username;

    private String password;

    private Boolean enable;

    @Bean("neo4jDriverDomain1")
    public org.neo4j.driver.Driver neo4jDriverDomain1() {
        System.out.println("neo4jDriverDomain1... url=" + this.uri + ",username=" + this.username + ",password=" + this.password);

        Config config = Config.builder()
                .withConnectionTimeout(10, TimeUnit.SECONDS)
                .withConnectionLivenessCheckTimeout(2, TimeUnit.MINUTES)
                .withMaxConnectionLifetime(4, TimeUnit.MINUTES)
                .withMaxConnectionPoolSize(20)
                .withConnectionAcquisitionTimeout(1, TimeUnit.MINUTES)
                .build();
        return GraphDatabase.driver(this.uri, AuthTokens.basic(this.username, this.password), config);
    }

    @Bean("ogmDriverDomain1")
    public Driver ogmDriverDomain1() {
        Driver ogmDriver = new BoltDriver(neo4jDriverDomain1());
        return ogmDriver;
    }

    @Bean(name = SESSION_FACTORY)
    public SessionFactory sessionFactory(ApplicationContext applicationContext) {
        String[] packages = getPackagesToScan(applicationContext);
        return new SessionFactory(ogmDriverDomain1(), packages);
    }

    @Bean(NEO4JTEMPLATE)
    public Neo4jTemplate neo4jTemplate1(){

        return new Neo4jTemplate(Neo4jClient.create(neo4jDriverDomain1()));

    }

//    @Bean(name = TRANSACTION_MANAGER) // <3>
//    public Neo4jTransactionManager neo4jTransactionManager(ApplicationContext applicationContext) {
//        System.out.println("==========neo4jTransactionManager1==========");
//        return new Neo4jTransactionManager(neo4jDriverDomain1());
//    }

    private String[] getPackagesToScan(ApplicationContext applicationContext) {
        List<String> packages = EntityScanPackages.get(applicationContext)
                .getPackageNames();
        if (packages.isEmpty() && AutoConfigurationPackages.has(applicationContext)) {
            packages = AutoConfigurationPackages.get(applicationContext);
        }
        return org.springframework.util.StringUtils.toStringArray(packages);
    }
}
